RecordFetchExec

Struct RecordFetchExec 

pub struct RecordFetchExec { /* private fields */ }
Physical plan node for fetching records from a RecordFetcher using row IDs produced by one or more index scans.

This operator takes one or more IndexFilters, builds an input plan to produce row IDs (by scanning and joining index results), and then uses a RecordFetcher to retrieve the actual data for those row IDs.

Implementations

Source

impl RecordFetchExec

pub fn try_new( indexes: Vec<IndexFilter>, limit: Option<usize>, record_fetcher: Arc<dyn RecordFetcher>, schema: SchemaRef, union_mode: UnionMode, ) -> Result<Self>

Create a new RecordFetchExec plan.

Arguments
  • indexes - Index filters to use for scanning
  • limit - Optional limit on the number of rows
  • record_fetcher - The fetcher to retrieve records by row ID
  • schema - Output schema
  • union_mode - Controls whether OR conditions use parallel or sequential union