pub struct RecordFetchExec { /* private fields */ }Expand description
Physical plan node for fetching records from a RecordFetcher using
row IDs produced by one or more index scans.
This operator takes one or more IndexFilters, builds an input plan
to produce row IDs (by scanning and joining index results), and then uses
a RecordFetcher to retrieve the actual data for those row IDs.
Implementations
Sourceimpl RecordFetchExec
impl RecordFetchExec
Sourcepub fn try_new(
indexes: Vec<IndexFilter>,
limit: Option<usize>,
record_fetcher: Arc<dyn RecordFetcher>,
schema: SchemaRef,
union_mode: UnionMode,
) -> Result<Self>
pub fn try_new( indexes: Vec<IndexFilter>, limit: Option<usize>, record_fetcher: Arc<dyn RecordFetcher>, schema: SchemaRef, union_mode: UnionMode, ) -> Result<Self>
Create a new RecordFetchExec plan.
Arguments
indexes- Index filters to use for scanninglimit- Optional limit on the number of rowsrecord_fetcher- The fetcher to retrieve records by row IDschema- Output schemaunion_mode- Controls whether OR conditions use parallel or sequential union